@@ -1,7 +1,7 @@
 library(testthat)
 library(stdmod)
 
-context("Check to_standardize")
+# context("Check to_standardize")
 
 dat <- test_x_1_w_1_v_1_cat1_n_500
 
@@ -25,50 +25,58 @@ stdmod_cxsw2 <- std_selected(lm_raw, to_scale = ~ mod, to_center = ~ iv, to_stan
 stdmod_cxsw3 <- std_selected(lm_raw, to_scale = ~ mod + v1, to_center = ~ v1 + iv)
 
 test_that("Standardize x", {
-    expect_equivalent(
-        coef(stdmod_x), coef(stdmod_x2)
+    expect_equal(
+        coef(stdmod_x), coef(stdmod_x2),
+        ignore_attr = TRUE
       )
   })
 
 test_that("Standardize y", {
-    expect_equivalent(
-        coef(stdmod_y), coef(stdmod_y2)
+    expect_equal(
+        coef(stdmod_y), coef(stdmod_y2),
+        ignore_attr = TRUE
       )
   })
 
 test_that("Standardize w", {
-    expect_equivalent(
-        coef(stdmod_w), coef(stdmod_w2)
+    expect_equal(
+        coef(stdmod_w), coef(stdmod_w2),
+        ignore_attr = TRUE
       )
   })
 
 test_that("Standardize xy", {
-    expect_equivalent(
-        coef(stdmod_xy), coef(stdmod_xy2)
+    expect_equal(
+        coef(stdmod_xy), coef(stdmod_xy2),
+        ignore_attr = TRUE
       )
   })
 
 test_that("Standardize xw", {
-    expect_equivalent(
-        coef(stdmod_xw), coef(stdmod_xw2)
+    expect_equal(
+        coef(stdmod_xw), coef(stdmod_xw2),
+        ignore_attr = TRUE
       )
   })
 
 test_that("Standardize yw", {
-    expect_equivalent(
-        coef(stdmod_yw), coef(stdmod_yw2)
+    expect_equal(
+        coef(stdmod_yw), coef(stdmod_yw2),
+        ignore_attr = TRUE
       )
   })
 
 test_that("Standardize x, y, and w", {
-    expect_equivalent(
-        coef(stdmod_xyw), coef(stdmod_xyw2)
+    expect_equal(
+        coef(stdmod_xyw), coef(stdmod_xyw2),
+        ignore_attr = TRUE
       )
   })
 
 test_that("Center x and scale w", {
-    expect_equivalent(
-        coef(stdmod_cxsw2), coef(stdmod_cxsw3)
+    expect_equal(
+        coef(stdmod_cxsw2), coef(stdmod_cxsw3),
+        ignore_attr = TRUE
       )
   })
 
@@ -92,28 +100,36 @@ stdmod_nb_cxsw2 <- std_selected_boot(lm_raw, to_scale = ~ mod, to_center = ~ iv,
 stdmod_nb_cxsw3 <- std_selected_boot(lm_raw, to_scale = ~ mod + v1, to_center = ~ v1 + iv, do_boot = FALSE)
 
 test_that("std_selected_boot with do_boot = FALSE", {
-    expect_equivalent(
-        coef(stdmod_nb_x), coef(stdmod_nb_x2)
+    expect_equal(
+        coef(stdmod_nb_x), coef(stdmod_nb_x2),
+        ignore_attr = TRUE
       )
-    expect_equivalent(
-        coef(stdmod_nb_y), coef(stdmod_nb_y2)
+    expect_equal(
+        coef(stdmod_nb_y), coef(stdmod_nb_y2),
+        ignore_attr = TRUE
       )
-    expect_equivalent(
-        coef(stdmod_nb_w), coef(stdmod_nb_w2)
+    expect_equal(
+        coef(stdmod_nb_w), coef(stdmod_nb_w2),
+        ignore_attr = TRUE
       )
-    expect_equivalent(
-        coef(stdmod_nb_xw), coef(stdmod_nb_xw2)
+    expect_equal(
+        coef(stdmod_nb_xw), coef(stdmod_nb_xw2),
+        ignore_attr = TRUE
       )
-    expect_equivalent(
-        coef(stdmod_nb_yw), coef(stdmod_nb_yw2)
+    expect_equal(
+        coef(stdmod_nb_yw), coef(stdmod_nb_yw2),
+        ignore_attr = TRUE
       )
-    expect_equivalent(
-        coef(stdmod_nb_xy), coef(stdmod_nb_xy2)
+    expect_equal(
+        coef(stdmod_nb_xy), coef(stdmod_nb_xy2),
+        ignore_attr = TRUE
       )
-    expect_equivalent(
-        coef(stdmod_nb_xyw), coef(stdmod_nb_xyw2)
+    expect_equal(
+        coef(stdmod_nb_xyw), coef(stdmod_nb_xyw2),
+        ignore_attr = TRUE
       )
-    expect_equivalent(
-        coef(stdmod_nb_cxsw2), coef(stdmod_nb_cxsw3)
+    expect_equal(
+        coef(stdmod_nb_cxsw2), coef(stdmod_nb_cxsw3),
+        ignore_attr = TRUE
       )
   })
